@@ -20,13 +20,13 @@ ColorFilterStrategyForeground::~ColorFilterStrategyForeground ()
 double ColorFilterStrategyForeground::pixelToZeroToOne (const QColor &pixel,
                                                         QRgb rgbBackground) const
 {
-  double distance = qSqrt (pow ((double) pixel.red()   - qRed   (rgbBackground), 2) +
-                           pow ((double) pixel.green() - qGreen (rgbBackground), 2) +
-                           pow ((double) pixel.blue()  - qBlue  (rgbBackground), 2));
+  double distance = qSqrt (pow (double (pixel.red())   - qRed   (rgbBackground), 2) +
+                           pow (double (pixel.green()) - qGreen (rgbBackground), 2) +
+                           pow (double (pixel.blue())  - qBlue  (rgbBackground), 2));
   return distance / qSqrt (255.0 * 255.0 + 255.0 * 255.0 + 255.0 * 255.0);
 }
 
 int ColorFilterStrategyForeground::zeroToOneToValue (double s) const
 {
-  return FOREGROUND_MIN + s * (FOREGROUND_MAX - FOREGROUND_MIN);
+  return qFloor (FOREGROUND_MIN + s * (FOREGROUND_MAX - FOREGROUND_MIN));
 }
