@@ -14,7 +14,11 @@ CreateHelpWindow::CreateHelpWindow()
 {
 }
 
-void CreateHelpWindow::create (MainWindow &mw)
+void CreateHelpWindow::create (MainWindow &
+#if !defined(OSX_DEBUG) && !defined(OSX_RELEASE)                               
+                               mw
+#endif                               
+                               )
 {
   LOG4CPP_INFO_S ((*mainCat)) << "CreateHelpWindow::create";
 
