@@ -36,10 +36,19 @@ DlgSettingsGridRemoval::DlgSettingsGridRemoval(MainWindow &mainWindow) :
   DlgSettingsAbstractBase (tr ("Grid Removal"),
                            "DlgSettingsGridRemoval",
                            mainWindow),
-  m_scenePreview (0),
-  m_viewPreview (0),
-  m_modelGridRemovalBefore (0),
-  m_modelGridRemovalAfter (0)
+  m_validatorCloseDistance (nullptr),
+  m_validatorCountX (nullptr),
+  m_validatorStartX (nullptr),
+  m_validatorStepX (nullptr),
+  m_validatorStopX (nullptr),      
+  m_validatorCountY (nullptr),
+  m_validatorStartY (nullptr),
+  m_validatorStepY (nullptr),
+  m_validatorStopY (nullptr),  
+  m_scenePreview (nullptr),
+  m_viewPreview (nullptr),
+  m_modelGridRemovalBefore (nullptr),
+  m_modelGridRemovalAfter (nullptr)
 {
   LOG4CPP_INFO_S ((*mainCat)) << "DlgSettingsGridRemoval::DlgSettingsGridRemoval";
 
@@ -50,6 +59,16 @@ DlgSettingsGridRemoval::DlgSettingsGridRemoval(MainWindow &mainWindow) :
 DlgSettingsGridRemoval::~DlgSettingsGridRemoval()
 {
   LOG4CPP_INFO_S ((*mainCat)) << "DlgSettingsGridRemoval::~DlgSettingsGridRemoval";
+
+  delete m_validatorCloseDistance;
+  delete m_validatorCountX;
+  delete m_validatorStartX;
+  delete m_validatorStepX;
+  delete m_validatorStopX;      
+  delete m_validatorCountY;
+  delete m_validatorStartY;
+  delete m_validatorStepY;
+  delete m_validatorStopY;
 }
 
 void DlgSettingsGridRemoval::createOptionalSaveDefault (QHBoxLayout * /* layout */)
@@ -161,7 +180,7 @@ void DlgSettingsGridRemoval::createRemoveGridLinesX (QGridLayout *layout, int &r
 
   m_editStepX = new QLineEdit;
   m_editStepX->setWhatsThis (tr ("Difference in value between two successive X grid lines.\n\n"
-                                 "The step value must be greater than zero"));
+                                 "The step value must be greater than zero (linear) or one (log)"));
   m_validatorStepX = new QDoubleValidator;
   m_editStepX->setValidator (m_validatorStepX);
   connect (m_editStepX, SIGNAL (textChanged (const QString &)), this, SLOT  (slotStepX (const QString &)));
@@ -239,7 +258,7 @@ void DlgSettingsGridRemoval::createRemoveGridLinesY (QGridLayout *layout, int &r
 
   m_editStepY = new QLineEdit;
   m_editStepY->setWhatsThis (tr ("Difference in value between two successive Y grid lines.\n\n"
-                                 "The step value must be greater than zero"));
+                                 "The step value must be greater than zero (linear) or one (log)"));
   m_validatorStepY = new QDoubleValidator;
   m_editStepY->setValidator (m_validatorStepY);
   connect (m_editStepY, SIGNAL (textChanged (const QString &)), this, SLOT  (slotStepY (const QString &)));
@@ -378,7 +397,7 @@ void DlgSettingsGridRemoval::slotDisableX(const QString &)
 {
   LOG4CPP_INFO_S ((*mainCat)) << "DlgSettingsGridRemoval::slotDisableX";
 
-  GridCoordDisable gridCoordDisable = (GridCoordDisable) m_cmbDisableX->currentData().toInt();
+  GridCoordDisable gridCoordDisable = static_cast<GridCoordDisable> (m_cmbDisableX->currentData().toInt());
   m_modelGridRemovalAfter->setGridCoordDisableX(gridCoordDisable);
   updateDisplayedVariableX ();
   updateControls();
@@ -389,7 +408,7 @@ void DlgSettingsGridRemoval::slotDisableY(const QString &)
 {
   LOG4CPP_INFO_S ((*mainCat)) << "DlgSettingsGridRemoval::slotDisableY";
 
-  GridCoordDisable gridCoordDisable = (GridCoordDisable) m_cmbDisableY->currentData().toInt();
+  GridCoordDisable gridCoordDisable = static_cast<GridCoordDisable> (m_cmbDisableY->currentData().toInt());
   m_modelGridRemovalAfter->setGridCoordDisableY(gridCoordDisable);
   updateDisplayedVariableY ();
   updateControls();
@@ -471,7 +490,7 @@ void DlgSettingsGridRemoval::updateControls ()
 
   m_cmbDisableX->setEnabled (m_chkRemoveGridLines->isChecked ());
 
-  GridCoordDisable disableX = (GridCoordDisable) m_cmbDisableX->currentData().toInt();
+  GridCoordDisable disableX = static_cast<GridCoordDisable> (m_cmbDisableX->currentData().toInt());
   m_editCountX->setEnabled (m_chkRemoveGridLines->isChecked () && (disableX != GRID_COORD_DISABLE_COUNT));
   m_editStartX->setEnabled (m_chkRemoveGridLines->isChecked () && (disableX != GRID_COORD_DISABLE_START));
   m_editStepX->setEnabled (m_chkRemoveGridLines->isChecked () && (disableX != GRID_COORD_DISABLE_STEP));
@@ -479,7 +498,7 @@ void DlgSettingsGridRemoval::updateControls ()
 
   m_cmbDisableY->setEnabled (m_chkRemoveGridLines->isChecked ());
 
-  GridCoordDisable disableY = (GridCoordDisable) m_cmbDisableY->currentData().toInt();
+  GridCoordDisable disableY = static_cast<GridCoordDisable> (m_cmbDisableY->currentData().toInt());
   m_editCountY->setEnabled (m_chkRemoveGridLines->isChecked () && (disableY != GRID_COORD_DISABLE_COUNT));
   m_editStartY->setEnabled (m_chkRemoveGridLines->isChecked () && (disableY != GRID_COORD_DISABLE_START));
   m_editStepY->setEnabled (m_chkRemoveGridLines->isChecked () && (disableY != GRID_COORD_DISABLE_STEP));
@@ -542,10 +561,6 @@ void DlgSettingsGridRemoval::updateDisplayedVariableX ()
                                                                       m_modelGridRemovalAfter->stepX (),
                                                                       m_modelGridRemovalAfter->countX ())));
       break;
-
-    default:
-      LOG4CPP_ERROR_S ((*mainCat)) << "DlgSettingsGridRemoval::updateDisplayedVariableX";
-      break;
   }
 }
 
@@ -583,10 +598,6 @@ void DlgSettingsGridRemoval::updateDisplayedVariableY ()
                                                                       m_modelGridRemovalAfter->stepY (),
                                                                       m_modelGridRemovalAfter->countY ())));
       break;
-
-    default:
-      LOG4CPP_ERROR_S ((*mainCat)) << "DlgSettingsGridRemoval::updateDisplayedVariableY";
-      break;
   }
 }
 
