@@ -9,14 +9,17 @@
 
 extern QString exportPointsSelectionRelationsToString (ExportPointsSelectionRelations exportPointsSelectionRelations)
 {
+  QString rtn;
+
   switch (exportPointsSelectionRelations) {
     case EXPORT_POINTS_SELECTION_RELATIONS_INTERPOLATE:
-      return QObject::tr ("Interpolate");
+      rtn = QObject::tr ("Interpolate");
+      break;
 
     case EXPORT_POINTS_SELECTION_RELATIONS_RAW:
-      return QObject::tr ("Raw");
-
-    default:
-      return QObject::tr ("Unknown");
+      rtn = QObject::tr ("Raw");
+      break;
   }
+
+  return rtn;
 }
