@@ -7,7 +7,9 @@
 #ifndef GEOMETRY_MODEL_H
 #define GEOMETRY_MODEL_H
 
+#include <QHash>
 #include <QString>
+#include <QVector>
 #include "WindowModelBase.h"
 
 /// Model that adds row highlighting according to the currently select point identifier
@@ -24,12 +26,18 @@ public:
   /// Set the point identifier to be highlighted. Value is empty for no highlighting
   void setCurrentPointIdentifier (const QString  &pointIdentifier);
 
+  /// Remember which rows could have ambiguities during export - these will be highlighted
+  void setPotentialExportAmbiguity (const QVector<bool> &isPotentialExportAmbiguity);
+
 private:
 
   int rowToBeHighlighted () const;
 
   int m_rowToBeHighlighted;
   QString m_pointIdentifier; // Point to be higlighted. Empty if none
+
+  // Row numbers with ambiguities
+  QHash<int, bool> m_ambiguousRows;
 };
 
 #endif // GEOMETRY_MODEL_H
