@@ -1,3 +1,4 @@
+#include "CallbackAxisPointsAbstract.h"
 #include "CallbackUpdateTransform.h"
 #include "Logger.h"
 #include "MainWindow.h"
@@ -6,6 +7,8 @@
 
 QTEST_MAIN (TestGraphCoords)
 
+const double EPSILON = 0.0;
+
 TestGraphCoords::TestGraphCoords(QObject *parent) :
   QObject(parent)
 {
@@ -19,6 +22,7 @@ void TestGraphCoords::cleanupTestCase ()
 
 void TestGraphCoords::initTestCase ()
 {
+  const bool NO_DROP_REGRESSION = false;
   const QString NO_ERROR_REPORT_LOG_FILE;
   const QString NO_REGRESSION_OPEN_FILE;
   const bool NO_GNUPLOT_LOG_FILES = false;
@@ -37,6 +41,7 @@ void TestGraphCoords::initTestCase ()
 
   MainWindow w (NO_ERROR_REPORT_LOG_FILE,
                 NO_REGRESSION_OPEN_FILE,
+                NO_DROP_REGRESSION,
                 NO_REGRESSION_IMPORT,                
                 NO_GNUPLOT_LOG_FILES,
                 NO_RESET,
@@ -56,7 +61,8 @@ void TestGraphCoords::testAnyColumnsRepeatNo ()
   vector.push_back (QPointF (300, 100));
   vector.push_back (QPointF (200, 200));
 
-  QVERIFY (!m_callback->anyPointsRepeatPair (vector));
+  QVERIFY (!m_callback->anyPointsRepeatPair (vector,
+                                             EPSILON));
 }
 
 void TestGraphCoords::testAnyColumnsRepeatYes ()
@@ -68,7 +74,8 @@ void TestGraphCoords::testAnyColumnsRepeatYes ()
   vector.push_back (QPointF (100, 100));
   vector.push_back (QPointF (200, 200));
 
-  QVERIFY (m_callback->anyPointsRepeatPair (vector));
+  QVERIFY (m_callback->anyPointsRepeatPair (vector,
+                                            EPSILON));
 }
 
 void TestGraphCoords::testThreeCollinearPointsNo ()
@@ -78,7 +85,9 @@ void TestGraphCoords::testThreeCollinearPointsNo ()
                 100, 150, 200,
                 1  , 1  , 1  );
 
-  QVERIFY (!m_callback->threePointsAreCollinear (m));
+  QVERIFY (!m_callback->threePointsAreCollinear (m,
+                                                 CallbackAxisPointsAbstract::LinearOrLog::COORD_IS_LINEAR,
+                                                 CallbackAxisPointsAbstract::LinearOrLog::COORD_IS_LINEAR));
 }
 
 void TestGraphCoords::testThreeCollinearPointsYes ()
@@ -88,5 +97,7 @@ void TestGraphCoords::testThreeCollinearPointsYes ()
                 100, 150, 200,
                 1  , 1  , 1  );
 
-  QVERIFY (m_callback->threePointsAreCollinear (m));
+  QVERIFY (m_callback->threePointsAreCollinear (m,
+                                                CallbackAxisPointsAbstract::LinearOrLog::COORD_IS_LINEAR,
+                                                CallbackAxisPointsAbstract::LinearOrLog::COORD_IS_LINEAR));
 }
