@@ -24,6 +24,7 @@ void TestGridLineLimiter::cleanupTestCase ()
 
 void TestGridLineLimiter::initTestCase ()
 {
+  const bool NO_DROP_REGRESSION = false;
   const QString NO_ERROR_REPORT_LOG_FILE;
   const QString NO_REGRESSION_OPEN_FILE;
   const bool NO_GNUPLOT_LOG_FILES = false;
@@ -42,6 +43,7 @@ void TestGridLineLimiter::initTestCase ()
 
   MainWindow w (NO_ERROR_REPORT_LOG_FILE,
                 NO_REGRESSION_OPEN_FILE,
+                NO_DROP_REGRESSION,
                 NO_REGRESSION_IMPORT,                
                 NO_GNUPLOT_LOG_FILES,
                 NO_RESET,
