@@ -30,6 +30,7 @@ void TestSegmentFill::cleanupTestCase ()
 
 void TestSegmentFill::initTestCase ()
 {
+  const bool NO_DROP_REGRESSION = false;
   const QString NO_ERROR_REPORT_LOG_FILE;
   const QString NO_REGRESSION_OPEN_FILE;
   const bool NO_GNUPLOT_LOG_FILES = false;
@@ -48,6 +49,7 @@ void TestSegmentFill::initTestCase ()
 
   MainWindow m (NO_ERROR_REPORT_LOG_FILE,
                 NO_REGRESSION_OPEN_FILE,
+                NO_DROP_REGRESSION,
                 NO_REGRESSION_IMPORT,
                 NO_GNUPLOT_LOG_FILES,
                 NO_RESET,
