@@ -33,6 +33,7 @@ double TestTransformation::differenceMagnitude (const QPointF &vector1,
 }
 void TestTransformation::initTestCase ()
 {
+  const bool NO_DROP_REGRESSION = false;
   const QString NO_ERROR_REPORT_LOG_FILE;
   const QString NO_REGRESSION_OPEN_FILE;
   const bool NO_GNUPLOT_LOG_FILES = false;
@@ -51,6 +52,7 @@ void TestTransformation::initTestCase ()
 
   MainWindow w (NO_ERROR_REPORT_LOG_FILE,
                 NO_REGRESSION_OPEN_FILE,
+                NO_DROP_REGRESSION,
                 NO_REGRESSION_IMPORT,
                 NO_GNUPLOT_LOG_FILES,
                 NO_RESET,
